==> haskell-x509-validation-1.6.11-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.11
id: x509-validation-1.6.11-HO70ECBArrDBe9mY9rG3av
key: x509-validation-1.6.11-HO70ECBArrDBe9mY9rG3av
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation. please see README
category: Data
abi: ac40862ecf3b725d72b9225e8cf56209
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-validation-1.6.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-validation-1.6.11
hs-libraries: HSx509-validation-1.6.11-HO70ECBArrDBe9mY9rG3av
depends:
    asn1-encoding-0.9.5-5XNOuE0nQHCK3G3olpJfim
    asn1-types-0.3.3-1mhyIh3E31bGLNcs6yGIdM base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hourglass-0.2.12-4t18e4DSgpnCTiyj5r8NVd
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB mtl-2.2.2
    pem-0.2.4-75UieA9BgyYAlSjfQh3jzj x509-1.7.5-BxUgjTTjNEXEbvLdaj4fTY
    x509-store-1.6.7-EuoJokF8SYrCiknYpI8XVB
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.11-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.11
id: x509-validation-1.6.11-46366fa7hWC4zLpobd0gw1
key: x509-validation-1.6.11-46366fa7hWC4zLpobd0gw1
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation. please see README
category: Data
abi: 5c47e951dec07c18adb798e86345c401
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/x509-validation-1.6.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/x509-validation-1.6.11
hs-libraries: HSx509-validation-1.6.11-46366fa7hWC4zLpobd0gw1
depends:
    asn1-encoding-0.9.5-EB58EapF6z449w8t1NTabZ
    asn1-types-0.3.3-7z9CB8aq8VCJkGLUUe9y5o base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hourglass-0.2.12-4t18e4DSgpnCTiyj5r8NVd
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth mtl-2.2.2
    pem-0.2.4-HncI1C63b9A2toAOPYDKsd x509-1.7.5-KqQg6Mi5Sp6LnkmIY5JGw2
    x509-store-1.6.7-KymLLv1sj8s4yZz7cgtnTm
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
